@@ -1,7 +1,7 @@
 `metaMDS` <-
     function (comm, distance = "bray", k = 2, trymax = 20, autotransform = TRUE, 
-              noshare = 0.1, expand = TRUE, trace = 1, plot = FALSE, previous.best, 
-              ...) 
+              noshare = 0.1, wascores = TRUE, expand = TRUE, trace = 1,
+              plot = FALSE, previous.best, ...) 
 {
     commname <- deparse(substitute(comm))
     if (inherits(comm, "dist"))
@@ -20,10 +20,14 @@
                       halfchange = (maxdis < 1.1), ...)
     if (is.null(rownames(points))) 
         rownames(points) <- rownames(comm)
-    wa <- wascores(points, comm, expand = expand)
+    if (wascores)
+        wa <- wascores(points, comm, expand = expand)
+    else
+        wa <- NA
     out$points <- points
     out$species <- wa
     out$call <- match.call()
     class(out) <- "metaMDS"
     out
 }
+
