@@ -4,7 +4,7 @@ function (formula, data, xlev = NULL)
     Terms <- terms(formula, "Condition", data = data)
     flapart <- fla <- formula <- formula(Terms, width.cutoff = 500)
     specdata <- formula[[2]]
-    X <- eval(specdata, data, environment(formula))
+    X <- eval.parent(specdata)
     X <- as.matrix(X)
     indPartial <- attr(Terms, "specials")$Condition
     mf <- Z <- NULL
